@@ -3,12 +3,12 @@ import hmac
 import base64
 from hashlib import sha1
 from uuid import uuid4
+import requests
 sid = None
 def sigg(data):
-        key=' fbf98eb3a07a9042ee5593b10ce9f3286a69d4e2'
-        mac = hmac.new(bytes.fromhex(key), data.encode("utf-8"), sha1)
-        digest = bytes.fromhex("32") + mac.digest()
-        return base64.b64encode(digest).decode("utf-8")
+  api = "https://ed-generators.herokuapp.com/"
+  p=requests.post(f"{api}/signature?data={data}").text
+  return p
 
 class Headers:
     def __init__(self, data = None, type = None, deviceId: str = None, sig: str = None):
@@ -21,7 +21,7 @@ class Headers:
             "NDCDEVICEID": dev.device_id,
             #"NDC-MSG-SIG": dev.device_id_sig,
             "Accept-Language": "en-US",
-            "Content-Type": "application/json; charset=utf-8",
+            "Content-Type": "application/json",
             "User-Agent": dev.user_agent,
             "Host": "service.narvii.com",
             "Accept-Encoding": "gzip",
