@@ -5,13 +5,12 @@ from hashlib import sha1
 from functools import reduce
 from base64 import b85decode, b64decode
 import random
+import requests
 import hmac
 import platform,socket,re,uuid 
 def dev():
-    hw=(names.get_full_name()+str(random.randint(0,10000000))+platform.version()+platform.machine()+names.get_first_name()+socket.gethostbyname(socket.gethostname())+':'.join(re.findall('..', '%012x' % uuid.getnode()))+platform.processor())
-    identifier=sha1(hw.encode('utf-8')).digest()
-    mac = hmac.new(bytes.fromhex('76b4a156aaccade137b8b1e77b435a81971fbd3e'), b"\x32" + identifier, sha1)
-    return (f"32{identifier.hex()}{mac.hexdigest()}").upper()
+  d=requests.get("https://ed-generators.herokuapp.com/device?").text
+  return d
 
 def generate_device_info():
     try:
