@@ -7,6 +7,7 @@ import base64
 import hmac
 import requests
 import time
+import urllib.parse
 import json
 from hashlib import sha1
 from sys import _getframe as getframe
@@ -99,6 +100,7 @@ class SocketHandler:
             print(f"[socket][start] Starting Socket")
            
         data = f"{self.client.device_id}|{int(time.time() * 1000)}"
+        edata=urllib.parse.quote_plus(data)
         #print(self.signature(data))
 
         self.headers = {
@@ -108,7 +110,7 @@ class SocketHandler:
         }
 
         self.socket = websocket.WebSocketApp(
-            f"{self.socket_url}/?signbody={self.client.device_id}%7C{int(time.time() * 1000)}",
+            f"{self.socket_url}/?signbody={edata}",
             on_message = self.handle_message,
             on_open = self.on_open,
             on_close = self.on_close,
